NUINotificationCountPayload class
- Inheritance
-
- Object
- NUIEnt<
NUINotificationCountPayload> - NUINotificationCountPayload
Constructors
- NUINotificationCountPayload({required int notificationCount})
- NUINotificationCountPayload.empty()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- notificationCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromJson(
Map< String, dynamic> json) → NUINotificationCountPayload -
inherited
-
mapper(
) → NUIEntMapper< NUINotificationCountPayload> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toMapQuery(
{Map< NUIEntType, EntCustomerMapper> ? customMapper}) → Map<String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited