NUIPushInboxMessage class

Inheritance

Constructors

NUIPushInboxMessage({required String notificationId, required String notificationDesc, required String notificationTitle, String? notificationType, String? image, required DateTime notificationDateTime, required bool isRead, String? itemId})
NUIPushInboxMessage.empty()

Properties

hashCode int
The hash code for this object.
no setterinherited
image String?
getter/setter pair
isRead bool
getter/setter pair
itemId String?
getter/setter pair
notificationDateTime DateTime
getter/setter pair
notificationDesc String
getter/setter pair
notificationId String
getter/setter pair
notificationTitle String
getter/setter pair
notificationType String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(Map<String, dynamic> json) NUIPushInboxMessage
inherited
mapper() → NUIEntMapper<NUIPushInboxMessage>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
inherited
toMapQuery({Map<NUIEntType, EntCustomerMapper>? customMapper}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited