NUIPushMessage class

Inheritance

Constructors

NUIPushMessage.empty()

Properties

actionType String?
getter/setter pair
body String?
getter/setter pair
category String?
getter/setter pair
data String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
image String?
getter/setter pair
opened bool
getter/setter pair
receivedAt String?
getter/setter pair
recipientId int
getter/setter pair
referenceTitle String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
getter/setter pair
url String?
getter/setter pair
webUrls List<String>?
getter/setter pair

Methods

fromJson(Map<String, dynamic> json) NUIPushMessage
inherited
mapper() → NUIEntMapper<NUIPushMessage>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toMap() Map<String, dynamic>
inherited
toMapQuery({Map<NUIEntType, EntCustomerMapper>? customMapper}) Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited