NUIPushMeta class
- Inheritance
-
- Object
- NUIEnt<
NUIPushMeta> - NUIPushMeta
Constructors
- NUIPushMeta({String? type, String? recipientId, String? actionType})
- NUIPushMeta.empty()
Properties
- actionType ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- recipientId ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
getter/setter pair
Methods
-
fromJson(
Map< String, dynamic> json) → NUIPushMeta -
inherited
-
mapper(
) → NUIEntMapper< NUIPushMeta> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toMapQuery(
{Map< NUIEntType, EntCustomerMapper> ? customMapper}) → Map<String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited