NUIPushNotification class

Inheritance

Constructors

NUIPushNotification({String? header, String? body, String? smallIcon, String? largeIcon, String? launchUrl, NUIPushMeta? meta, Map<String, dynamic>? data, OSNotification? osNotification})
NUIPushNotification.empty()

Properties

body ↔ String?
getter/setter pair
data ↔ Map<String, dynamic>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
largeIcon ↔ String?
getter/setter pair
launchUrl ↔ String?
getter/setter pair
meta ↔ NUIPushMeta?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallIcon ↔ String?
getter/setter pair

Methods

fromJson(Map<String, dynamic> json) → NUIPushNotification
inherited
mapper() → NUIEntMapper<NUIPushNotification>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toMap() → Map<String, dynamic>
inherited
toMapQuery({Map<NUIEntType, EntCustomerMapper>? customMapper}) → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited