NUIPushOSNotification class

Inheritance

Constructors

NUIPushOSNotification({required String appId, required Map<String, String> headings, required Map<String, String> contents, Map<String, String>? subtitle, String? android_channel_id, String? huawei_channel_id, String? bigPicture, String? huawei_big_picture, Map<String, dynamic>? data, List<String>? includePlayerIds, List<String>? includedSegments, List<String>? excludedSegments})
NUIPushOSNotification.empty()

Properties

android_channel_id ↔ String?
getter/setter pair
appId ↔ String
getter/setter pair
bigPicture ↔ String?
getter/setter pair
contents ↔ Map<String, String>
getter/setter pair
data ↔ Map<String, dynamic>?
getter/setter pair
excludedSegments ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headings ↔ Map<String, String>
getter/setter pair
huawei_big_picture ↔ String?
getter/setter pair
huawei_channel_id ↔ String?
getter/setter pair
includedSegments ↔ List<String>?
getter/setter pair
includePlayerIds ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ Map<String, String>?
getter/setter pair

Methods

fromJson(Map<String, dynamic> json) → NUIPushOSNotification
inherited
mapper() → NUIEntMapper<NUIPushOSNotification>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toMap() → Map<String, dynamic>
inherited
toMapQuery({Map<NUIEntType, EntCustomerMapper>? customMapper}) → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited