NUIPushStandardResponse<T> class
- Inheritance
-
- Object
- NUIEnt<
NUIPushStandardResponse< T> > - NUIPushStandardResponse
Constructors
- NUIPushStandardResponse(NUIEntType dataType, DataSetter dataSetter)
Properties
- data ↔ T?
-
getter/setter pair
- dataSetter → DataSetter
-
final
- dataType → NUIEntType
-
final
- errorCode ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ bool?
-
getter/setter pair
Methods
-
fromJson(
Map< String, dynamic> json) → NUIPushStandardResponse<T> -
inherited
-
mapper(
) → NUIEntMapper< NUIPushStandardResponse< T> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toMapQuery(
{Map< NUIEntType, EntCustomerMapper> ? customMapper}) → Map<String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited