NUIRegisterPushDeviceRequest class
- Inheritance
-
- Object
- NUIEnt<
NUIRegisterPushDeviceRequest> - NUIRegisterPushDeviceRequest
Constructors
- NUIRegisterPushDeviceRequest({required String userId, String? uniqueId, required String providerDeviceToken, String? deviceModel, String? deviceOs})
- NUIRegisterPushDeviceRequest.empty()
Properties
- deviceModel ↔ String?
-
getter/setter pair
- deviceOs ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerDeviceToken ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uniqueId ↔ String?
-
getter/setter pair
- userId ↔ String
-
getter/setter pair
Methods
-
fromJson(
Map< String, dynamic> json) → NUIRegisterPushDeviceRequest -
inherited
-
mapper(
) → NUIEntMapper< NUIRegisterPushDeviceRequest> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toMap(
) → Map< String, dynamic> -
inherited
-
toMapQuery(
{Map< NUIEntType, EntCustomerMapper> ? customMapper}) → Map<String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited