NUIPushBuilder class

Constructors

NUIPushBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

baseUrl(String baseUrl) NUIPushBuilder
build() Future<NUIPush>
disableInAppMessage(bool disable) NUIPushBuilder
Default value is true
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notificationOpenedListener(NUIPushNotificationListener listener) NUIPushBuilder
notificationReceivedListener(NUIPushNotificationListener listener) NUIPushBuilder
oneSignalAppId(String appId) NUIPushBuilder
oneSignalAuthKey(String oneSignalAuthKey) NUIPushBuilder
overwriteWebBuilder(NUIWebBuilder webBuilder) NUIPushBuilder
The module will be replaced with NUIPush.NUIWEB_MODULE The baseURL will be replaced with _baseUrl
toString() String
A string representation of this object.
inherited
userID(String userId) NUIPushBuilder
userIDChangedListener(NUIPushUserIDListener listener) NUIPushBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited