changeUserId abstract method

Future<DataResult> changeUserId(
  1. String userId, {
  2. bool reRegister = false,
})

Use it when user login or logout, to change the userId that associated to the current device. Another use case could be, verify user token when initialize the application, if the token expired, change the external ID

Implementation

Future<DataResult> changeUserId(String userId, {bool reRegister = false});