getInboxNotifications abstract method
Get all the notifications from the current user inbox
Implementation
Future<DataResult<List<NUIPushInboxMessage>>> getInboxNotifications({required int page, required int limit});
Get all the notifications from the current user inbox
Future<DataResult<List<NUIPushInboxMessage>>> getInboxNotifications({required int page, required int limit});